[llvm-commits] CVS: llvm/include/llvm/Target/MRegisterInfo.h TargetFrameInfo.h

Evan Cheng evan.cheng at apple.com
Tue Jan 2 13:30:32 PST 2007



Changes in directory llvm/include/llvm/Target:

MRegisterInfo.h updated: 1.85 -> 1.86
TargetFrameInfo.h updated: 1.21 -> 1.22
---
Log message:

Fix naming inconsistency: calleesave -> calleesaved.

---
Diffs of the changes:  (+18 -18)

 MRegisterInfo.h   |   30 +++++++++++++++---------------
 TargetFrameInfo.h |    6 +++---
 2 files changed, 18 insertions(+), 18 deletions(-)


Index: llvm/include/llvm/Target/MRegisterInfo.h
diff -u llvm/include/llvm/Target/MRegisterInfo.h:1.85 llvm/include/llvm/Target/MRegisterInfo.h:1.86
--- llvm/include/llvm/Target/MRegisterInfo.h:1.85	Tue Jan  2 14:55:17 2007
+++ llvm/include/llvm/Target/MRegisterInfo.h	Tue Jan  2 15:30:17 2007
@@ -283,16 +283,16 @@
     return false;
   }
 
   /// getCalleeSaveRegs - Return a null-terminated list of all of the
   /// callee-save registers on this target. The register should be in the
   /// order of desired callee-save stack frame offset. The first register is
   /// closed to the incoming stack pointer if stack grows down, and vice versa.
-  virtual const unsigned* getCalleeSaveRegs() const = 0;
+  virtual const unsigned* getCalleeSavedRegs() const = 0;
 
   /// getCalleeSaveRegClasses - Return a null-terminated list of the preferred
   /// register classes to spill each callee-saved register with.  The order and
   /// length of this list match the getCalleeSaveRegs() list.
-  virtual const TargetRegisterClass* const *getCalleeSaveRegClasses() const = 0;
+  virtual const TargetRegisterClass* const *getCalleeSavedRegClasses() const =0;
 
   //===--------------------------------------------------------------------===//
   // Register Class Information
@@ -320,22 +320,22 @@
   // immediates and memory.  FIXME: Move these to TargetInstrInfo.h.
   //
 
   /// spillCalleeSaveRegisters - Issues instruction(s) to spill all callee saved
   /// registers and returns true if it isn't possible / profitable to do so by
   /// issuing a series of store instructions via storeRegToStackSlot(). Returns
   /// false otherwise.
-  virtual bool spillCalleeSaveRegisters(MachineBasicBlock &MBB,
-                                        MachineBasicBlock::iterator MI,
+  virtual bool spillCalleeSavedRegisters(MachineBasicBlock &MBB,
+                                         MachineBasicBlock::iterator MI,
                                 const std::vector<CalleeSavedInfo> &CSI) const {
     return false;
   }
 
   /// restoreCalleeSaveRegisters - Issues instruction(s) to restore all callee
   /// saved registers and returns true if it isn't possible / profitable to do
   /// so by issuing a series of load instructions via loadRegToStackSlot().
   /// Returns false otherwise.
-  virtual bool restoreCalleeSaveRegisters(MachineBasicBlock &MBB,
-                                          MachineBasicBlock::iterator MI,
+  virtual bool restoreCalleeSavedRegisters(MachineBasicBlock &MBB,
+                                           MachineBasicBlock::iterator MI,
                                 const std::vector<CalleeSavedInfo> &CSI) const {
     return false;
   }
@@ -394,10 +394,10 @@
     assert(0 && "Call Frame Pseudo Instructions do not exist on this target!");
   }
 
   /// processFunctionBeforeCalleeSaveScan - This method is called immediately
   /// before PrologEpilogInserter scans the physical registers used to determine
-  /// what callee-save registers should be spilled. This method is optional.
-  virtual void processFunctionBeforeCalleeSaveScan(MachineFunction &MF) const {
+  /// what callee saved registers should be spilled. This method is optional.
+  virtual void processFunctionBeforeCalleeSavedScan(MachineFunction &MF) const {
   }
 
   /// processFunctionBeforeFrameFinalized - This method is called immediately
@@ -283,16 +283,16 @@
   }
 
-  /// getCalleeSaveRegs - Return a null-terminated list of all of the
-  /// callee-save registers on this target. The register should be in the
+  /// getCalleeSavedRegs - Return a null-terminated list of all of the
+  /// callee saved registers on this target. The register should be in the
   /// order of desired callee-save stack frame offset. The first register is
   /// closed to the incoming stack pointer if stack grows down, and vice versa.
@@ -283,16 +283,16 @@
 
-  /// getCalleeSaveRegClasses - Return a null-terminated list of the preferred
-  /// register classes to spill each callee-saved register with.  The order and
+  /// getCalleeSavedRegClasses - Return a null-terminated list of the preferred
+  /// register classes to spill each callee saved register with.  The order and
   /// length of this list match the getCalleeSaveRegs() list.
@@ -320,22 +320,22 @@
   //
 
-  /// spillCalleeSaveRegisters - Issues instruction(s) to spill all callee saved
+  /// spillCalleeSavedRegisters - Issues instruction(s) to spill all callee saved
   /// registers and returns true if it isn't possible / profitable to do so by
   /// issuing a series of store instructions via storeRegToStackSlot(). Returns
@@ -320,22 +320,22 @@
   }
 
-  /// restoreCalleeSaveRegisters - Issues instruction(s) to restore all callee
+  /// restoreCalleeSavedRegisters - Issues instruction(s) to restore all callee
   /// saved registers and returns true if it isn't possible / profitable to do
   /// so by issuing a series of load instructions via loadRegToStackSlot().
@@ -394,10 +394,10 @@
   }
 
-  /// processFunctionBeforeCalleeSaveScan - This method is called immediately
+  /// processFunctionBeforeCalleeSavedScan - This method is called immediately
   /// before PrologEpilogInserter scans the physical registers used to determine


Index: llvm/include/llvm/Target/TargetFrameInfo.h
diff -u llvm/include/llvm/Target/TargetFrameInfo.h:1.21 llvm/include/llvm/Target/TargetFrameInfo.h:1.22
--- llvm/include/llvm/Target/TargetFrameInfo.h:1.21	Thu Aug  3 13:55:44 2006
+++ llvm/include/llvm/Target/TargetFrameInfo.h	Tue Jan  2 15:30:17 2007
@@ -61,8 +61,8 @@
   ///
   int getOffsetOfLocalArea() const { return LocalAreaOffset; }
 
   /// getCalleeSaveSpillSlots - This method returns a pointer to an array of
   /// pairs, that contains an entry for each callee save register that must be
   /// spilled to a particular stack location if it is spilled.
   ///
   /// Each entry in this array contains a <register,offset> pair, indicating the
@@ -71,7 +71,7 @@
   /// allowed to spill it anywhere it chooses.
   ///
   virtual const std::pair<unsigned, int> *
-  getCalleeSaveSpillSlots(unsigned &NumEntries) const {
+  getCalleeSavedSpillSlots(unsigned &NumEntries) const {
     NumEntries = 0;
     return 0;
   }
@@ -61,8 +61,8 @@
   int getOffsetOfLocalArea() const { return LocalAreaOffset; }
 
-  /// getCalleeSaveSpillSlots - This method returns a pointer to an array of
-  /// pairs, that contains an entry for each callee save register that must be
+  /// getCalleeSavedSpillSlots - This method returns a pointer to an array of
+  /// pairs, that contains an entry for each callee saved register that must be
   /// spilled to a particular stack location if it is spilled.
   ///






More information about the llvm-commits mailing list